@@ -92,7 +92,6 @@ static const GOptionEntry options[] = {
 	{ "pid",        '\0', 0, G_OPTION_ARG_INT,      &gopt_data.pid,           N_("PID of crashed program"),                  N_("PID") },
 	{ "include",    '\0', 0, G_OPTION_ARG_FILENAME, &gopt_data.include_file,  N_("Text file to include in the report"),      N_("FILE") },
 	{ "unlink-tempfile", '\0', 0, G_OPTION_ARG_NONE, &gopt_data.own_file,     N_("Delete the included file after reporting"),NULL},
-	{ "minidump",   '\0', 0, G_OPTION_ARG_FILENAME, &gopt_data.minidump_file, N_("MiniDump file with info about the crash"), N_("FILE") },
 	{ "version", '\0', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, show_version_cb, NULL, NULL },
 	{ NULL }
 };
@@ -796,7 +795,7 @@ send_report (BugzillaApplication *app, GnomeVersionInfo *gnome_version, GtkBuild
 	email = gtk_entry_get_text (GTK_ENTRY (gtk_builder_get_object (ui, "email-entry")));
 	title = create_report_title (app, type, details_text);
 
-	message = bugzilla_create_report (app, type, gnome_version, email, title, final_text, ui, gopt_data.minidump_file, &err);
+	message = bugzilla_create_report (app, type, gnome_version, email, title, final_text, ui, &err);
 	if (message == NULL) {
 		char *text;
 
@@ -1150,39 +1149,6 @@ create_debuginfo_link (void)
 	return urlbutton;
 }
 
-
-static void
-add_minidump_text_output (const char *minidump_file, GtkBuilder *ui)
-{
-	GtkTextView *text_view;
-	GtkTextIter end;
-	GtkTextBuffer *buffer;
-	gchar *command_line;
-	gchar *standard_output, *standard_error;
-	gint exit_status;
-	GError *error;
-
-
-	text_view = GTK_TEXT_VIEW (gtk_builder_get_object (ui, "gdb-text"));
-	buffer = gtk_text_view_get_buffer (text_view);
-	gtk_text_buffer_get_end_iter (buffer, &end);
-
-	command_line = g_strdup_printf ("minidump_dump %s", minidump_file);
-	if (g_spawn_command_line_sync (command_line, &standard_output, &standard_error,
-				      &exit_status, &error)) {
-		gtk_text_buffer_insert (buffer, &end, standard_output, strlen (standard_output));
-		g_free (standard_output);
-		g_free (standard_error);
-	} else {
-		g_error_free (error);
-	}
-
-}
-
-
-
-
-
 static void
 useless_finished (GtkBuilder *ui)
 {
@@ -1393,10 +1359,6 @@ unknown_app_finished (GtkBuilder *ui)
 
 	fill_stderr_info (ui);
 
-	if (gopt_data.minidump_file) {
-		add_minidump_text_output (gopt_data.minidump_file, ui);
-	}
-	
 	/* don't need user input, so hide these widgets */
 	gtk_widget_hide (GTK_WIDGET (gtk_builder_get_object (ui, "final-box")));
 	gtk_widget_hide (GTK_WIDGET (gtk_builder_get_object (ui, "progressbar")));
@@ -1890,6 +1852,55 @@ fill_stderr_info (GtkBuilder *ui)
 	g_string_free (stderr_info, TRUE);
 }
 
+
+static gboolean
+has_gdb (void)
+{
+	gchar *gdb = g_find_program_in_path ("gdb");
+	if (gdb) {
+		g_free (gdb);
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
+static gboolean
+is_gnome_hacker (void)
+{
+	if (g_getenv ("GNOME_HACKER"))
+		return TRUE;
+
+	return FALSE;
+}
+
+static gboolean
+run_gdb (const gchar *appname, pid_t pid)
+{
+	gchar *exec_str;
+	gchar *title;
+	gboolean res;
+	GError *error = NULL;
+
+	title = g_strdup_printf ("Debugging %s", appname);
+
+	exec_str = g_strdup_printf ("gnome-terminal "
+				    "--title=\"%s\" "
+				    "--disable-factory "
+				    "--command=\"gdb %s %d\"",
+				    title, appname, (int) pid);
+	g_free (title);
+	res = g_spawn_command_line_sync (exec_str, NULL, NULL,
+					 NULL, &error);
+	g_free (exec_str);
+	if (!res) {
+		g_warning ("Couldn't run debugger\n");
+		return FALSE;
+	}
+
+	return TRUE;
+}
+
 int
 main (int argc, char *argv[])
 {
@@ -1931,6 +1942,26 @@ main (int argc, char *argv[])
 	g_set_application_name (_("Bug Buddy"));
 	gtk_window_set_default_icon_name ("bug-buddy");
 
+	if (gopt_data.app_file && gopt_data.pid) {
+		if (has_gdb () && is_gnome_hacker ()) {
+			gboolean res;
+			res = run_gdb (gopt_data.app_file, gopt_data.pid);
+			if (!res)
+				_exit (1);
+			_exit(0);
+		}
+	 	if (!has_gdb ()) {
+			/* FIXME: Request PackageKit to install gdb */
+			_exit(0);
+		}
+		
+		if (!elf_has_debug_symbols (gopt_data.pid)) {
+			/* FIXME: Request PackageKit to install debug symbols packages */
+			_exit(0);
+		}
+
+	}
+
 	s = g_build_filename (BUDDY_DATADIR, "bug-buddy.gtkbuilder", NULL);
 
 	ui = gtk_builder_new ();
@@ -1966,9 +1997,8 @@ main (int argc, char *argv[])
 	}	
 
 	if (gopt_data.app_file && gopt_data.pid == 0 && 
-            gopt_data.include_file == NULL && 
-            gopt_data.minidump_file == NULL) {
-		buddy_error (NULL, _("Either --pid , --include or --minidump arguments are required.\n"));	
+            gopt_data.include_file == NULL) {
+		buddy_error (NULL, _("Either --pid or --include arguments are required.\n"));	
 		return 0;
 	}
 
