@@ -22,7 +22,6 @@
 
 #include <glib.h>
 #include <gtk/gtk.h>
-#include <libgnomevfs/gnome-vfs.h>
 #include <bonobo-activation/bonobo-activation.h>
 
 #include "bugzilla.h"
@@ -51,8 +50,7 @@ main (int argc, char *argv[])
 	GHashTable *apps;
 
 	gtk_init (&argc, &argv);
-	gnome_vfs_init ();
-	
+
 	if (!bonobo_activation_is_initialized()) {
 		bonobo_activation_init (argc, argv);
 	}
